import { ApiFetchConfig, ApiGetConfig, ApiPageResponse, ApiParamType, ApiPostConfig, ApiResponse, ApiUploadConfig, Pageable, Sortable } from './types';
/**
 * fetch函数
 * @param param 请求配置信息
 * @returns Promise对象
 */
export declare const fetch: <RESP>({ url, method, headers, params, data, contentType, responseType, timeout, onProgress, baseURL }: ApiFetchConfig) => Promise<RESP>;
/**
 * 上传函数
 * @param config 请求配置信息
 * @returns Promise对象
 */
export declare const upload: <RESP>(config: ApiUploadConfig) => Promise<ApiResponse<RESP>>;
/**
 * Json Get函数
 * @param config 请求配置信息
 * @returns
 */
export declare const get: <RESP>(config: ApiGetConfig) => Promise<ApiResponse<RESP>>;
/**
 * Post函数
 * @param config 请求配置信息
 * @returns
 */
export declare const post: <RESP>(config: ApiPostConfig) => Promise<ApiResponse<RESP>>;
/**
 * 分页Get函数
 * <RESP> 返回类型
 * @param config 请求配置信息
 * @returns
 */
export declare const getPage: <RESP>(config: ApiGetConfig & {
    page: Pageable;
    sort?: Sortable;
}) => Promise<ApiPageResponse<RESP>>;
/**
 * 分页Post函数
 * @param config 请求配置信息
 * @returns
 */
export declare const postPage: <RESP>(config: ApiPostConfig & {
    page: Pageable;
    sort?: Sortable;
}) => Promise<ApiPageResponse<RESP>>;
/**
 * 定义一个Upload函数
 * @param <RESP> 返回类型
 * @param <PARAM> 请求参数的类型
 * @param config 请求的配置信息
 * @param defaultParam 请求的默认参数
 * @returns 一个请求函数
 */
export declare const defineUploadApi: <RESP = any, PARAM = ApiParamType>(config: Omit<ApiUploadConfig, 'params' | 'data'>, defaultParam?: Partial<PARAM>) => (data: FormData, params?: PARAM, onProgress?: ApiUploadConfig['onProgress']) => Promise<ApiResponse<RESP>>;
/**
 * 定义一个Get函数
 * @param <RESP> 返回类型
 * @param <DATA> Form数据的类型
 * @param <PARAM> 请求参数的类型
 * @param config 请求的配置信息
 * @param defaultParam 请求的默认参数
 * @returns 一个请求函数
 */
export declare const defineGetApi: <RESP = any, PARAM = ApiParamType>(config: Omit<ApiGetConfig, 'params'>, defaultParam?: Partial<PARAM>) => (params?: PARAM) => Promise<ApiResponse<RESP>>;
/**
 * 定义一个分页Get函数
 * @param <RESP> 返回类型
 * @param <PARAM> 请求参数的类型
 * @param config 请求的配置信息
 * @param defaultParam 请求的默认参数
 * @returns 一个分页请求函数
 */
export declare const defineGetPageApi: <RESP = any, PARAM = ApiParamType>(config: Omit<ApiGetConfig, 'params'>, defaultParam?: Partial<PARAM>) => (params: PARAM, page: Pageable, sort?: Sortable) => Promise<ApiPageResponse<RESP>>;
/**
 * 定义一个Post函数
 * @param <RESP> 返回类型
 * @param <DATA> Post数据的类型
 * @param <PARAM> 请求参数的类型
 * @param config 请求的配置信息
 * @param defaultParam 请求的默认参数
 * @returns 一个请求函数
 */
export declare const definePostApi: <RESP = any, DATA = ApiParamType, PARAM = ApiParamType>(config: Omit<ApiPostConfig, 'params' | 'data'>, defaultParam?: Partial<PARAM>) => (data: DATA, params?: PARAM) => Promise<ApiResponse<RESP>>;
/**
 * 定义一个分页Post函数
 * @param <RESP> 返回类型
 * @param <DATA> Post数据的类型
 * @param <PARAM> 请求参数的类型
 * @param config 请求的配置信息
 * @param defaultParam 请求的默认参数
 * @returns 一个分页请求函数
 */
export declare const definePostPageApi: <RESP, DATA = ApiParamType, PARAM = ApiParamType>(config: Omit<ApiPostConfig, 'params' | 'data'>, defaultParam?: Partial<PARAM>) => (data: DATA, page: Pageable, params?: PARAM, sort?: Sortable) => Promise<ApiPageResponse<RESP>>;
